@@ -7,6 +7,7 @@
 #include "listitemmenu.h"
 
 #include <QAbstractItemModel>
+#include <QActionGroup>
 #include <QMenu>
 #include <QQuickItem>
 #include <QQuickWindow>
@@ -319,7 +320,7 @@ QMenu *ListItemMenu::createMenu()
         return nullptr;
     }
 
-    QMenu *menu = new QMenu();
+    auto *menu = new QMenu();
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
     connect(menu, &QMenu::aboutToHide, this, [this] {
@@ -445,7 +446,7 @@ QMenu *ListItemMenu::createMenu()
                         menu->addSection(title);
                     }
 
-                    QActionGroup *profileGroup = new QActionGroup(profilesMenu);
+                    auto *profileGroup = new QActionGroup(profilesMenu);
                     for (auto it = availableProfiles.constBegin(), end = availableProfiles.constEnd(); it != end; ++it) {
                         const int i = it.key();
                         Profile *profile = it.value();
